@@ -42,7 +42,7 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.043_01';
+our $VERSION = '0.043_02';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
@@ -359,6 +359,11 @@ sub find_regexp {
     return wantarray ? ( $-[0] + 0, $+[0] + 0 ) : $+[0] + 0;
 }
 
+sub get_mode {
+    my ( $self ) = @_;
+    return $self->{mode};
+}
+
 sub get_start_delimiter {
     my ( $self ) = @_;
     return $self->{delimiter_start};
@@ -1225,6 +1230,10 @@ This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
 
+=head2 get_mode
+
+This method returns the name of the current mode of the tokenizer.
+
 =head2 get_start_delimiter
 
  my $start_delimiter = $tokenizer->get_start_delimiter();
